@@ -1,4 +1,5 @@
-from collections import ChainMap, Mapping
+from collections import ChainMap
+from collections.abc import Mapping
 from functools import partial
 from os import PathLike
 from pathlib import Path
@@ -44,4 +45,3 @@ class YAMLLoader(AbstractConfigLoader):
 
     def __str__(self):
         return f"{self.__class__.__name__}: {self.config_path}"
-
